@@ -73,6 +73,7 @@ CREDITS = dict(
         'abidin toumi (Arabic)',
         'Rayen Ghanmi (Arabic)',
         'Mohamed Abdalah Noh (Arabic)',
+        'Ahmed Najmawi (Arabic)',
         'Rafael Fontenelle (Brazilian Portuguese)',
         'Infinitive Witch (Brazilian Portuguese)',
         'Unidealistic Raccoon (Brazilian Portuguese)',
@@ -80,6 +81,7 @@ CREDITS = dict(
         'Juliano de Souza Camargo (Brazilian Portuguese)',
         'Giovanne Menicheli (Brazilian Portuguese)',
         'Fúlvio Alves (Brazilian Portuguese)',
+        'Felipe (Brazilian Portuguese)',
         'twlvnn (Bulgarian)',
         'Roger VC (Catalan)',
         'Lukáš Linhart (Czech)',
@@ -110,15 +112,18 @@ CREDITS = dict(
         'Tim (German)',
         'Sear Gasor (German)',
         'Vortex Acherontic (German)',
+        'Dlurak (German)',
         'Scrambled777 (Hindi)',
         'mondstern (Hungarian)',
         'Milo Ivir (Croatian)',
         'Alifiyan Rosyidi (Indonesian)',
         'Alim Satria (Indonesian)',
         'Juan Manuel (Indonesian)',
+        'srntskl-111 (Indonesian)',
         'Mek101 (Italian)',
         'dedocc (Italian)',
         'Davide Mora (Italian)',
+        'Andrea Scarano (Italian)',
         'Lili Kurek (Polish)',
         'Aleksander Warzyniak (Polish)',
         'ssantos (Portuguese)',
@@ -534,27 +539,29 @@ available in your region/language."""))
 
         # Override release notes
         dialog.set_release_notes("""
+            <p>This is a bugfix version.</p>
             <ul>
-                <li>[Servers] ريبر العربي (AR): Disabled</li>
-                <li>[Servers] 3asq (AR): Disabled</li>
-                <li>[Servers] Dango Scan (pt_BR): Update</li>
-                <li>[Servers] DB New Hope (EN/ES/FR): Update</li>
-                <li>[Servers] Dynasty Reader (EN): Update</li>
-                <li>[Servers] EZmanga (EN): Ignored chapters with price</li>
-                <li>[Servers] Mangago (EN): Update</li>
+                <li>[Card] Fixed Pull-to-Update</li>
+            </ul>
+
+            <p>Changes in previous version 1.79.0</p>
+            <ul>
+                <li>[Card] Added new backdrop method: Blurred cover</li>
+                <li>[Servers] Dragon Ball Multiverse: Update</li>
+                <li>[Servers] EZmanga (EN): Update</li>
+                <li>[Servers] MangaCrab (ES): Update</li>
+                <li>[Servers] MangaMana (FR): Update</li>
+                <li>[Servers] MangaNato (EN): Update</li>
                 <li>[Servers] Mangaowl (EN): Update</li>
-                <li>[Servers] MangaReader (EN): Update</li>
-                <li>[Servers] MangaWorld (IT): Update</li>
-                <li>[Servers] Manhwa Hentai (EN): Disabled</li>
-                <li>[Servers] Mint Manga (RU): Disabled</li>
-                <li>[Servers] Nazarick Scan (pt_BR): Update</li>
-                <li>[Servers] PhenixScans (FR): Update</li>
-                <li>[Servers] Reaper Scans (EN): Update</li>
+                <li>[Servers] MangaReader (cc) (EN): Update</li>
+                <li>[Servers] Neko Scans(ES): Update</li>
+                <li>[Servers] Pepper&amp;Carrot: Added support of Persian language</li>
+                <li>[Servers] Rawdevart (JA): Update</li>
+                <li>[Servers] Read Comic Online (EN): Update</li>
+                <li>[Servers] Senpai Ediciones (ES): Disabled</li>
                 <li>[Servers] Terco Scans (EN): Update</li>
-                <li>[Servers] Tres Daos (ES): Update</li>
-                <li>[Servers] View Comics (EN): Update</li>
-                <li>[Servers] Xoxocomics (EN): Update</li>
-                <li>[L10n] Updated French and Russian translations</li>
+                <li>[Servers] Usagi (RU): Disabled</li>
+                <li>[L10n] Updated Arabic and Persian translations</li>
             </ul>
             <p>Happy reading.</p>
         """)
